#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-DLn43Ul2XF9BhzC7AGbKob
key:                  ghcide-2.3.0.0-DLn43Ul2XF9BhzC7AGbKob
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  630539eb3ba008a9c25ad1354e8f79ff
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-DLn43Ul2XF9BhzC7AGbKob
depends:
    Diff-0.5-Bzm6xo6eDfTG6RHTd0lKvx Glob-0.10.2-97Xu7vJtRPSJLacTEKTWHc
    aeson-2.2.1.0-AeqJOB7WzlfHEyTUHodGhY array-0.5.6.0
    async-2.2.6-JFqXkyZWakA6MSvky6jlwB base-4.18.2.1
    base16-bytestring-1.0.2.0-8g6yC3fsg2K6nyARuCXVuM binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-IhPAKZHiECkGPRzzh8aBPd
    co-log-core-0.3.2.6-3CUAWo0ZrT017RrHeSToiu containers-0.6.7
    cryptohash-sha1-0.11.101.0-5HTqHLT0Zf4Acm8DXUaDG1
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    dependent-map-0.4.0.1-C0vVVdgGAwHAK9EhRp7nCo
    dependent-sum-0.7.2.0-KwB3b9ZwKc1DvNge4WO5l7 directory-1.3.8.5
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    enummapset-0.7.3.0-H9aCwdV78nL4XTv2iojLpn exceptions-0.10.7
    extra-1.7.16-GG4oQL1Pbvk2YReVs3ucdi filepath-1.4.300.1
    fingertree-0.1.6.3-I7dWmCXmnb9Hzc75cCbtPr
    focus-1.0.3.2-7PcSwTz2QnLCcO0JfZywJm ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-BuFZkuuqRHc2SkNyd995aQ
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-JJAOZlwC8cWHmAbAmnRzjc
    hashable-1.4.7.0-8qGpYVybfmaKH8giGSMaAG
    hie-bios-0.12.0-7wMlOF17eexL5h7CRXf36U
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-2B7vm1Eb57pDjxvRObkxot
    hls-graph-2.3.0.0-1B5GSgbN5tgFODBfL8MjR9
    hls-plugin-api-2.3.0.0-HZFnlB4uroEI1syiyMmKGx
    implicit-hie-0.1.4.0-6LMNXWNZrXCq7KmIPwpZq
    implicit-hie-cradle-0.5.0.1-FukWsGrG4NfLfZNKbU38eX
    lens-5.3.4-CkqmOXVchFg1U8XPLp3M2a
    list-t-1.0.5.7-2IKNsiyb21aLpVbJDKGNaY
    lsp-2.2.0.0-3J7slxQP1ui8QijUPoiGpE
    lsp-types-2.0.2.0-3ytSjIj1khG9WTocufKZ9I mtl-2.3.1
    opentelemetry-0.8.0-V88JciDhrrLgebTR810A3
    optparse-applicative-0.18.1.0-64q3Zt8gfMnAm6zpFRaIVN
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.1-LD9ksSCydFQDqbwXyaukvW
    prettyprinter-ansi-terminal-1.1.3-896KymlkjfV2aLJdomya30
    random-1.2.1.3-Fpl3dUa1VuLH6jaWIu29Ly
    regex-tdfa-1.3.2.5-7pJaUTnbPYM9Za1KnP0Rwp
    row-types-1.0.1.2-LM8qEc4gaw56rg4gzlM3UB
    safe-exceptions-0.1.7.4-AUKG3QHTD7NLfABqrCKWM8
    sorted-list-0.2.3.1-JxcnWXKTOq34yGmimwNo4L
    sqlite-simple-0.4.19.0-E0yyMyfgc7hJmZGvlGU993 stm-2.5.1.0
    stm-containers-1.2.1.1-LAggKtGptQ29QFMq7kJ2Zt
    syb-0.7.3-LrvXJMjYPlcHf68JytS4Q text-2.0.2
    text-rope-0.3-AbOSPWrPz0yIUUa2OLVnoe time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-7sXhGHm93AhzYdedcIgQ6
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-9qHVoc2smYt9flJ6feRxGY
    vector-0.13.2.0-AWRowWUrdYO1choGzrrEgg

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

